import unittest
from posturner import trans_universal_pos
class TestStringMethods(unittest.TestCase):
    def test_trans_universal_pos(self):
        result = trans_universal_pos("adjective")
        assert result == "ADJ"
        result = trans_universal_pos("unknown")
        self.assertEqual(result, "X")
        result = trans_universal_pos("det")
        self.assertEqual(result, "PRON")
        result = trans_universal_pos("onomatopoeia")
        self.assertEqual(result, "INTJ")


pos_set = {"Adjektiv": "ADJ", "Adposition": "ADP", "Adverb": "ADV", "Hilfsmittel": "AUX", "Koordinierung der Verbindung": "CCONJ", "Determinator": "DET", "Interjektion": "INTJ", "Substantiv": "NOUN", "Zahlf": "NUM", "Partikel": "PART", "Pronomen": "PRON", "Eigennamen": "PROPN", "Zeichensetzung": "PUNCT", "untergeordnete Konjunktion": "SCONJ", "Symbol": "SYM", "Verb": "VERB", "andere": "X", "adjective": "ADJ", "adposition": "ADP", "adverb": "ADV", "auxiliary": "AUX", "coordinating conjunction": "CCONJ", "determiner": "DET", "interjection": "INTJ", "noun": "NOUN", "numeral": "NUM", "particle": "X", "pronoun": "PRON", "proper noun": "PROPN", "punctuation": "PUNCT", "subordinating conjunction": "SCONJ", "symbol": "SYM", "verb": "VERB", "other": "X", "omadussõna": "ADJ", "adpositsioon": "ADP", "abivahendid": "AUX", "kooskõlastamine": "CCONJ", "määratleja": "DET", "vaheldumine": "INTJ", "nimisõna": "NOUN", "number": "NUM", "osakesed": "PART", "asesõna": "PRON", "pärisnimi": "PROPN", "vahemärgid": "PUNCT", "allutav konjunktsioon": "SCONJ", "sümbol": "SYM", "muud": "X", "形容詞": "ADJ", "副詞": "ADV", "ほじょ": "AUX", "ちょうせいはいごう": "CCONJ", "そくていき": "DET", "感嘆詞": "INTJ", "名詞": "NOUN", "数値＃スウスウ＃": "NUM", "びりゅうし": "PART", "代名詞": "PRON", "固有名詞": "PROPN", "句読点": "PUNCT", "従属連語": "SCONJ", "記号": "SYM", "動詞": "VERB", "その他": "X", "Приложение": "ADJ", "Добавление": "ADP", "наречие": "ADV", "Вспомогательный": "AUX", "Координация": "CCONJ", "Измеритель": "DET", "Воспоминания": "INTJ", "Терминология": "NOUN", "Цифры": "NUM", "Частицы": "PART", "местоимение": "PRON", "Собственные термины": "PROPN", "Пунктуация": "PUNCT", "зависимый союз": "SCONJ", "Символы": "SYM", "Глагол": "VERB", "Прочее": "X", "Adjetivo": "ADJ", "Colocación": "ADP", "Adverbio": "ADV", "Auxiliar": "AUX", "Coordinación y cooperación": "CCONJ", "Determinador": "DET", "Exclamación": "INTJ", "Sustantivo": "NOUN", "Números": "NUM", "Partículas": "PART", "Pronósticos": "PRON", "Término propio": "PROPN", "Puntuación": "PUNCT", "Conjunción subordinada": "SCONJ", "Símbolo": "SYM", "Verbos": "VERB", "Otros": "X", "abbrev": "PROPN", "adj_noun": "NOUN", "adj_verb": "VERB", "adj": "ADJ", "adnominal": "ADJ", "adv": "ADV", "adv_phrase": "ADV", "affix": "X", "suffix": "X", "ambiposition": "X", "article": "X", "character": "X", "circumfix": "X", "circumpos": "X", "classifier": "PROPN", "combining_form": "X", "conj": "X", "contraction": "contraction", "converb": "X", "counter": "X", "dets": "DET", "phrase": "PROPN", "infix": "X", "interfix": "X", "intj": "INTJ", "pron": "PRON", "clause": "X", "num": "NUM", "postp": "X", "prefix": "X", "prep": "PREP", "prep_phrase": "X", "preverb": "VERB", "name": "PROPN", "proverb": "VERB", "punct": "PUNCT", "romanization": "X", "root": "X", "syllable": "SYM", "unknown": "X", "det": "PRON", "onomatopoeia": "INTJ", "形容词": "ADJ", "介词": "ADP", "副词": "ADV", "助词": "AUX", "协调连词": "CCONJ", "限定词": "DET", "感叹词": "INTJ", "名词": "NOUN", "数词": "NUM", "短语": "PART", "代词": "PRON", "专有名词": "PROPN", "标点符号": "PUNCT", "从属连词": "SCONJ", "符号": "SYM", "动词": "VERB", "其他": "X"}


import setuptools

with open("README.md", "r",encoding='utf-8') as f:
    long_description = f.read()

setuptools.setup(
    name="posturner",
    version="0.1.6",
    author="Feliks Peegel",
    author_email="felikspeegel@outlook.com",
    description="transfrom different language pos tags to universal pos tags.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/felikspeegel/posturner",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires=">=3.6",
)
